==> dde-launchpad_1.99.1.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>AnalysisView</name>
    <message>
        <source>No search results</source>
        <translation type="obsolete">Nessun risultato disponibile</translation>
    </message>
</context>
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Invia al desktop</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Rimuovi dal desktop</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Rimuovi dalla dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Invia alla dock</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Aggiungi all&apos;avvio automatico</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Rimuovi dall&apos;avvio automatico</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Usa un proxy</translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Disinstalla</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Musica</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Grafica</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Ufficio</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Lettura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Sviluppo</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">Sistema</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation type="unfinished">Alimentazione</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="56"/>
        <source>Search</source>
        <translation type="unfinished">Cerca</translation>
    </message>
    <message>
        <location filename="../qml/windowed/BottomBar.qml" line="103"/>
        <source>Full-screen Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="obsolete">Tutte le app</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Cerca</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="152"/>
        <source>Window Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation type="unfinished">Internet</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation type="unfinished">Chat</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation type="unfinished">Musica</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation type="unfinished">Grafica</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation type="unfinished">Ufficio</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation type="unfinished">Lettura</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation type="unfinished">Sviluppo</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation type="unfinished">Sistema</translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="411"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="423"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/Main.qml" line="437"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation type="unfinished">Tutte le app</translation>
    </message>
    <message>
        <location filename="../qml/FullscreenFrame.qml" line="545"/>
        <location filename="../qml/windowed/SearchResultView.qml" line="102"/>
        <source>No search results</source>
        <translation type="unfinished">Nessun risultato disponibile</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Power</source>
        <translation type="vanished">Alimentazione</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Impostazioni</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Cerca</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="vanished">I miei Preferiti</translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="vanished">Tutte le app</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="vanished">Nessun risultato disponibile</translation>
    </message>
</context>
</TS>

==> dde-launchpad_1.99.9.tar.xz: BUILD/shell-launcher-applet/translations/org.deepin.ds.dock.launcherapplet_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it">
<context>
    <name>AnalysisView</name>
    <message>
        <source>No search results</source>
        <translation type="obsolete">Nessun risultato disponibile</translation>
    </message>
</context>
<context>
    <name>AppItemMenu</name>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="34"/>
        <source>Open</source>
        <translation>Apri</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="46"/>
        <source>Pin to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="55"/>
        <source>Move to Top</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Remove from favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="65"/>
        <source>Add to favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Send to desktop</source>
        <translation>Invia al desktop</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="80"/>
        <source>Remove from desktop</source>
        <translation>Rimuovi dal desktop</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Remove from dock</source>
        <translation>Rimuovi dalla dock</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="91"/>
        <source>Send to dock</source>
        <translation>Invia alla dock</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Add to startup</source>
        <translation>Aggiungi all&apos;avvio automatico</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="103"/>
        <source>Remove from startup</source>
        <translation>Rimuovi dall&apos;avvio automatico</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="111"/>
        <source>Use a proxy</source>
        <translation>Usa un proxy</translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="120"/>
        <source>Disable display scaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/AppItemMenu.qml" line="127"/>
        <source>Uninstall</source>
        <translation>Disinstalla</translation>
    </message>
</context>
<context>
    <name>AppListView</name>
    <message>
        <source>Internet</source>
        <translation type="vanished">Internet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation type="vanished">Chat</translation>
    </message>
    <message>
        <source>Music</source>
        <translation type="vanished">Musica</translation>
    </message>
    <message>
        <source>Video</source>
        <translation type="vanished">Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="vanished">Grafica</translation>
    </message>
    <message>
        <source>Office</source>
        <translation type="vanished">Ufficio</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation type="vanished">Lettura</translation>
    </message>
    <message>
        <source>Development</source>
        <translation type="vanished">Sviluppo</translation>
    </message>
    <message>
        <source>System</source>
        <translation type="vanished">Sistema</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="32"/>
        <source>Power</source>
        <translation type="unfinished">Alimentazione</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="58"/>
        <source>Search</source>
        <translation type="unfinished">Cerca</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/BottomBar.qml" line="105"/>
        <source>Full-screen Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="27"/>
        <source>Install</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/DummyAppItemMenu.qml" line="34"/>
        <source>Remove</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <location filename="../../qml/windowed/FrequentlyUsedView.qml" line="36"/>
        <source>Frequently Used</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="obsolete">Tutte le app</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Search</source>
        <translation type="obsolete">Cerca</translation>
    </message>
    <message>
        <location filename="../../qml/FullscreenFrame.qml" line="152"/>
        <source>Window Mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LauncherController</name>
    <message>
        <location filename="../../launchercontroller.cpp" line="19"/>
        <source>Show launcher (hidden by default)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../launchercontroller.cpp" line="20"/>
        <source>Toggle launcher visibility</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <location filename="../../qml/Main.qml" line="22"/>
        <source>Internet</source>
        <translation type="unfinished">Internet</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="24"/>
        <source>Chat</source>
        <translation type="unfinished">Chat</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="26"/>
        <source>Music</source>
        <translation type="unfinished">Musica</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="28"/>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="30"/>
        <source>Graphics</source>
        <translation type="unfinished">Grafica</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="32"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="34"/>
        <source>Office</source>
        <translation type="unfinished">Ufficio</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="36"/>
        <source>Reading</source>
        <translation type="unfinished">Lettura</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="38"/>
        <source>Development</source>
        <translation type="unfinished">Sviluppo</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="40"/>
        <source>System</source>
        <translation type="unfinished">Sistema</translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="42"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="411"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="423"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/Main.qml" line="437"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <location filename="../../qml/windowed/RecentlyInstalledView.qml" line="34"/>
        <source>Recently Installed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="37"/>
        <source>All Apps</source>
        <translation type="unfinished">Tutte le app</translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SearchResultView.qml" line="102"/>
        <location filename="../../qml/FullscreenFrame.qml" line="545"/>
        <source>No search results</source>
        <translation type="unfinished">Nessun risultato disponibile</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="40"/>
        <source>Free sorting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="54"/>
        <source>Sort by category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="66"/>
        <source>Sort by name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="90"/>
        <source>Sorting Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="145"/>
        <source>Computer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="156"/>
        <source>Pictures</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="167"/>
        <source>Documents</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="178"/>
        <source>Desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../qml/windowed/SideBar.qml" line="189"/>
        <source>Control Center</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Power</source>
        <translation type="vanished">Alimentazione</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="vanished">Impostazioni</translation>
    </message>
    <message>
        <source>Search</source>
        <translation type="vanished">Cerca</translation>
    </message>
    <message>
        <source>My Favorites</source>
        <translation type="vanished">I miei Preferiti</translation>
    </message>
    <message>
        <source>All Apps</source>
        <translation type="vanished">Tutte le app</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="vanished">Nessun risultato disponibile</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <location filename="../package/launcheritem.qml" line="110"/>
        <source>Internet</source>
        <translation type="unfinished">Internet</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="112"/>
        <source>Chat</source>
        <translation type="unfinished">Chat</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="114"/>
        <source>Music</source>
        <translation type="unfinished">Musica</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="116"/>
        <source>Video</source>
        <translation type="unfinished">Video</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="118"/>
        <source>Graphics</source>
        <translation type="unfinished">Grafica</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="120"/>
        <source>Game</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="122"/>
        <source>Office</source>
        <translation type="unfinished">Ufficio</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="124"/>
        <source>Reading</source>
        <translation type="unfinished">Lettura</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="126"/>
        <source>Development</source>
        <translation type="unfinished">Sviluppo</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="128"/>
        <source>System</source>
        <translation type="unfinished">Sistema</translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="130"/>
        <source>Others</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="140"/>
        <source>launchpad</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="268"/>
        <source>Are you sure you want to uninstall %1?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="280"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../package/launcheritem.qml" line="294"/>
        <source>Confirm</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
